namespace Quadratic.Carto.Orbital;

/// <summary>
/// Provides commonly used physical constants.
/// </summary>
public static class PhysicalConstants
{
    /// <summary>
    /// The speed of light in a vacuum, in meters per second.
    /// </summary>
    public const double LightSpeed = 299_792_458.0;

    /// <summary>
    /// The gravitational constant, in cubic meters per kilogram per second squared.
    /// </summary>
    public const double GravitationalConstant = 6.67430e-11;

    /// <summary>
    /// Alias for the speed of light in a vacuum, in meters per second.
    /// </summary>
    public const double c = LightSpeed;

    /// <summary>
    /// Alias for the gravitational constant, in cubic meters per kilogram per second squared.
    /// </summary>
    public const double G = GravitationalConstant;
}
